
/**
 * Zależności modułu.
 */

var express = require('express')
  , mongoose = require('mongoose')

/**
 * Konfiguracja aplikacji.
 */

app = express.createServer()

/**
 * Metody pośredniczące.
 */

app.use(express.bodyParser());
app.use(express.cookieParser());
app.use(express.session({ secret: 'moj sekret' }));

/**
 * Określ opcje widoku.
 */

app.set('view engine', 'jade');
app.set('view options', { layout: false });

/**
 * Metody pośredniczące do uwierzytelnienia.
 */

app.use(function (req, res, next) {
  if (req.session.loggedIn) {
    res.local('authenticated', true);
    User.findById(req.session.loggedIn, function (err, doc) {
      if (err) return next(err);
      res.local('me', doc);
      next();
    });
  } else {
    res.local('authenticated', false);
    next();
  }
});

/**
 * Domyślna trasa
 */

app.get('/', function (req, res) {
  res.render('index');
});

/**
 * Trasa logowania
 */

app.get('/login/:signupEmail?', function (req, res) {
  res.render('login', { signupEmail: req.params.signupEmail });
});

/**
 * Trasa przetwarzania logowania
 */

app.post('/login', function (req, res) {
  User.findOne({ email: req.body.user.email, password: req.body.user.password }, function (err, doc) {
    if (err) return next(err);
    if (!doc) return res.send('<p>Nie znaleziono użytkownika. Wróć do poprzedniej strony i spróbuj ponownie.');
    req.session.loggedIn = doc._id.toString();
    res.redirect('/');
  });
});

/**
 * Trasa rejestracji
 */

app.get('/signup', function (req, res) {
  res.render('signup');
});

/**
 * Trasa przetwarzania rejestracji
 */

app.post('/signup', function (req, res, next) {
  var user = new User(req.body.user);
  user.save(function (err) {
    if (err) return next(err);
    res.redirect('/login/' + user.email);
  });
});

/**
 * Trasa wylogowywania.
 */

app.get('/logout', function (req, res) {
  req.session.loggedIn = null;
  res.redirect('/');
});

/**
 * Połącz się z bazą danych.
 */

mongoose.connect('mongodb://127.0.0.1/my-website');
app.listen(3000, function () {
  console.log('\033[96m  + \033[39m aplikacja nasłuchuje na porcie *:3000');
});

/**
 * Zdefiniuj model.
 */

var Schema = mongoose.Schema

var User = mongoose.model('User', new Schema({
    first: String
  , last: String
  , email: { type: String, unique: true }
  , password: { type: String, index: true }
}));
